SUCCESS = 10000
AUTH_NONE = 10001
AUTH_NOT_EXIST = 10002
AUTH_ERROR_SIGN = 10003
AUTH_TIMEOUT = 10004
AUTH_CALC_ERROR = 10005
AUTH_REQUEST_FAST = 10006
REQUEST_PARAM_INVALID = 10007

USER_NOT_EXIST = 11001
USER_CLOSE_FOLLOW = 11002
USER_IMAGE_NONE = 11003
USER_IMAGE_FORMAT_ERROR = 11004
USER_IMAGE_OPEN_ERROR = 11005
USER_MEMORY_NOT_ENOUGH = 11006
USER_IMAGE_NOT_EXIST = 11007

PROBLEM_NOT_EXIST = 12001
PROBLEM_PEMISSION_DENIED = 12002
PROBLEM_SHEET_NOT_EXIST = 12101
PROBLEM_SHEET_PEMISSION_DENIED = 12102

CONTEST_NOT_EXIST = 13001
CONTEST_PERMISSION_DENIED = 13002

TEAM_NOT_EXIST = 14001
TEAM_PERMISSION_DENIED = 14002
TEAM_NO_MEMBER = 14003
TEAM_METHOD_PERMISSION_DENIED = 14004
TEAM_PROBLEM_NOT_EXIST = 14101
TEAM_PROBELM_PERMISSION_DENIED = 14102
TEAM_CONTEST_NOT_EXIST = 14201
TEAM_CONTEST_PERMISSION_DENIED = 14202
